@@ -1,21 +1,21 @@
-## Copyright (C) 1996 Auburn University.  All rights reserved.
+## Copyright (C) 1996, 2000, 2004, 2005, 2007
+##               Auburn University.  All rights reserved.
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
-## Octave is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301 USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} bddemo (@var{inputs})
@@ -28,8 +28,8 @@
 
 function bddemo ()
 
-  sav_page = page_screen_output;
-  page_screen_output = 1;
+  sav_page = page_screen_output ();
+  page_screen_output (1);
 
   while (1)
     clc
@@ -609,5 +609,5 @@ function bddemo ()
     endif
   endwhile
   implict_str_to_num_ok = str_sav;
-  page_screen_output = sav_page;
+  page_screen_output  (sav_page);
 endfunction
