@@ -1228,7 +1228,7 @@ function configure_make (desc, packdir, verbose)
       if (isempty (getenv ("RANLIB")))
         flags = strcat (flags, " RANLIB=\"", octave_config_info ("RANLIB"), "\"");
       endif
-      [status, output] = shell (strcat ("cd ", src, "; ./configure --prefix=\"",
+      [status, output] = shell (strcat ("cd '", src, "'; ./configure --prefix=\"",
                                         desc.dir, "\"", flags));
       if (status != 0)
 	rm_rf (desc.dir);
@@ -1242,7 +1242,7 @@ function configure_make (desc, packdir, verbose)
     ## make
     if (exist (fullfile (src, "Makefile"), "file"))
       [status, output] = shell (strcat ("export INSTALLDIR=\"", desc.dir,
-					 "\"; gmake -C ", src));
+ 					 "\"; gmake -C '", src, "'"));
       if (status != 0)
 	rm_rf (desc.dir);
 	error ("'make' returned the following error: %s", output);
@@ -1281,21 +1281,10 @@ function configure_make (desc, packdir, verbose)
       m = dir (fullfile (src, "*.m"));
       oct = dir (fullfile (src, "*.oct"));
       mex = dir (fullfile (src, "*.mex"));
-      archdependent = "";
-      archindependent = "";
-      filenames = "";
-      if (length (m) > 0)
-	filenames = sprintf (fullfile (src, "%s "), m.name);
-      endif
-      if (length (oct) > 0)
-	filenames = strcat (filenames, " ",
-			    sprintf (fullfile (src, "%s "), oct.name));
-      endif
-      if (length (mex) > 0)
-	filenames = strcat (filenames, " ",
-			    sprintf (fullfile (src, "%s "), mex.name));
-      endif
-      filenames = split_by (filenames, " ");
+
+      filenames = cellfun (@(x) fullfile (src, x),
+			   {m.name, oct.name, mex.name},
+			   "UniformOutput", false);
     endif
 
     ## Split into architecture dependent and independent files
